@@ -49,13 +49,12 @@ def _format(response):
     return result
 
 class Payment:
-    def __init__(self, url, private_key: str, public_key: str, payment_type: str, site_id: str, seller_site_id: str):
+    def __init__(self, url, private_key: str, public_key: str, payment_type: str, site_id: str):
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
         self.payment_type = payment_type
         self.site_id = site_id
-        self.seller_site_id = seller_site_id
         self.headers = {
             'apikey': self.private_key,
             'Content-Type': 'application/json',
